@@ -766,10 +766,11 @@ class Dict(Trafaret):
     >>> trafaret.check({"foo": 1, "bar": "spam", "ham": 100, "baz": None})
     >>> extract_error(trafaret, {"foo": 1, "ham": 100, "baz": None})
     {'bar': 'is required'}
-    >>> trafaret = Dict({Key('bar', optional=True): String}, foo=Int) >> ignore
+    >>> trafaret = Dict({Key('bar', optional=True): String}, foo=Int)
     >>> trafaret.allow_extra("*")
     <Dict(any | bar=<String>, foo=<Int>)>
     >>> trafaret.check({"foo": 1, "ham": 100, "baz": None})
+    {'foo': 1, 'baz': None, 'ham': 100}
     >>> extract_error(trafaret, {"bar": 1, "ham": 100, "baz": None})
     {'foo': 'is required', 'bar': 'value is not string'}
     >>> extract_error(trafaret, {"foo": 1, "bar": 1, "ham": 100, "baz": None})
@@ -836,7 +837,7 @@ class Dict(Trafaret):
                 if not self.allow_any and key not in self.extras:
                     errors[key] = DataError("%s is not allowed key" % key)
                 else:
-                    collect[key] = data
+                    collect[key] = data[key]
         if errors:
             raise DataError(error=errors)
         return collect
@@ -945,7 +946,7 @@ class Callable(Trafaret):
             self._failure("value is not callable")
 
     def __repr__(self):
-        return "<CallableC>"
+        return "<Callable>"
 
 
 class Call(Trafaret):
@@ -958,7 +959,7 @@ class Call(Trafaret):
     ...
     >>> trafaret = Call(validator)
     >>> trafaret
-    <CallC(validator)>
+    <Call(validator)>
     >>> trafaret.check("foo")
     'foo'
     >>> extract_error(trafaret, "bar")
@@ -967,10 +968,10 @@ class Call(Trafaret):
 
     def __init__(self, fn):
         if not callable(fn):
-            raise RuntimeError("CallC argument should be callable")
+            raise RuntimeError("Call argument should be callable")
         argspec = inspect.getargspec(fn)
         if len(argspec.args) - len(argspec.defaults or []) > 1:
-            raise RuntimeError("CallC argument should be"
+            raise RuntimeError("Call argument should be"
                                " one argument function")
         self.fn = fn
 
@@ -982,7 +983,7 @@ class Call(Trafaret):
             return res
 
     def __repr__(self):
-        return "<CallC(%s)>" % self.fn.__name__
+        return "<Call(%s)>" % self.fn.__name__
 
 
 class Forward(Trafaret):
